package koboldsim

import (
	"git.chromaticdragon.app/kistaro/CardSimEngine/cardsim"
)

var cards = []Card{
	&SwitchingCard{ // Card 1
		Name:  cardsim.MsgStr("Warborn"),
		Desc:  cardsim.MsgStr(" A surge of anti-kobold sentiment has been reported by your spies on the surface and your military is concerned that anti-kobold vigilantes will attack the tunnels in the near-future.  They want to build up now while doing so is safe."),
		After: ShuffleIntoBottomHalf,
		Policies: []Policy{
			&TablePolicy{
				UnenactedDesc: cardsim.MsgStr(`Your war chief paces irritably.  "We have terrible threats facing us.  It's imperative that we build up our numbers in both the military and the domestic sense.  I want creches under military control and a good hunting crew to supply them with food."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Your war chief is presently monitoring the situation, building up your military, and securing your creches."),
				EffectsTable: map[FieldLabel]float64{
					BasePopulation:   100,
					Scavenging:       1,
					Militarism:       2,
					FoodSupply:       1,
					ForeignRelations: -2,
					Rebellion:        -3,
					Madness:          1,
					Cruelty:          1,
					Authoritarianism: 4,
				},
				EnactionDesc: cardsim.MsgStr("Kobolds are known to be born warriors."),
				CanDo:        YesWeAlsoCan,
			},
			&TablePolicy{
				UnenactedDesc: cardsim.MsgStr(`Your head miner considers the matter worriedly.  "Creches under military control?  No.  That would invite chaos.  We need to dig deeper; we can have a peaceful, orderly society if we just get far enough away from surfacers."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Your head miner is presently leading a project to dig as far away from the surface as possible."),
				EffectsTable: map[FieldLabel]float64{
					BasePopulation: 40,
					Mining:         2,
					Construction:   1,
					Manufacturing:  1,
					Bureaucracy:    1,
					FoodSupply:     -1,
					Secrecy:        3,
				},
				EnactionDesc: cardsim.MsgStr("Kobolds are known to be cowards hiding in the dark."),
				CanDo:        YesWeAlsoCan,
			},
			&TablePolicy{
				UnenactedDesc: cardsim.MsgStr(`Your nursery director is incensed.  "Creches under military control?  Never!  Let young kobolds play!  In fact, cut the military just for suggesting this.  The threats facing us are completely overstated."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Military funding has been diverted into early childhood education."),
				EffectsTable: map[FieldLabel]float64{
					BasePopulation:   -40,
					Scavenging:       -1,
					Militarism:       -2,
					Education:        1,
					FoodSupply:       -2,
					ForeignRelations: 2,
					Madness:          -1,
					Cruelty:          -1,
				},
				EnactionDesc: cardsim.MsgStr("An undefended hunting outpost near the surface was recently wiped out by a raid."),
				CanDo:        YesWeAlsoCan,
			},
			&VerbosePolicy{
				Default: &TablePolicy{
					UnenactedDesc: cardsim.MsgStr("This isn't about a disaster and can probably be safely dismissed."),
					EffectsTable: map[FieldLabel]float64{
						BasePopulation: 20,
					},
					EnactionDesc: cardsim.MsgStr("Creche control doesn't shift that easily."),
					CanDo:        YesWeAlsoCan,
				},
				Variants: []Policy{
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Rejecting this issue will also reject the military's natalist stance."),
						Do:            OverrideMsg(cardsim.MsgStr("Militant natalism has been reduced by policy.")),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr(`"Dig deeper" pressures in your tribe may be excessive.`),
						Do:            OverrideMsg(cardsim.MsgStr("Some of the lower depths are being abandoned.")),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Near-surface patrols may need to be increased."),
						Do:            OverrideMsg(cardsim.MsgStr("More and better-armed hunting outposts are being established.")),
					},
					&BasicPolicy{
						EnactedDesc: cardsim.MsgStr("This isn't about a disaster and can probably continue to be safely dismissed."),
						Do:          OverrideMsg(cardsim.MsgStr("Creche control doesn't shift that easily.")),
					},
				},
			},
		}, // End of "Warborn" policies
	}, // End of "Warborn" card
	&SwitchingCard{ // Card 2
		Name:  cardsim.MsgStr("Pan-Tribal Festival of Bureaucracy"),
		Desc:  cardsim.MsgStr(" Good times are upon us! A great festival has been declared between many kobold tribes, celebrating the orderly nature of the kobold soul!  That's right, it's the Pan-Tribal Festival of Bureaucracy!"),
		After: ShuffleIntoBottomHalf,
		Policies: []Policy{
			&TablePolicy{
				UnenactedDesc: cardsim.MsgStr(`Your Minister of Administration is practically jumping for joy. "This is our opportunity to prove that we're a prosperous society and attract some fresh blood!  We need to raise salaries in the bureaucracy, grant some time off to our bureaucrats to make sure they can attend, and try to hire talent away from other tribes.  We'll forge productive trade relations by this, you'll see!`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Your bureaucrats are really looking forward to attending, where they can boast about how the festival boosted their salaries."),
				EffectsTable: map[FieldLabel]float64{
					BasePopulation: 60,
					Scavenging:     1,
					Bureaucracy:    3,
					FoodSupply:     1,
					Gullibility:    -1,
				},
				EnactionDesc: cardsim.MsgStr("Bureaucrats are considered pillars of society."),
				CanDo:        YesWeAlsoCan,
			},
			&TablePolicy{
				UnenactedDesc: cardsim.MsgStr(`Your Minister of Finance pulls you aside. "This is a good opportunity to head-hunt.  Bureaucrats from many tribes will be attending.  There's got to be some who'll work for less than the ones we've got.  There are some terribly threatened or impoverished communities among kobolds.`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Your tribe's policy is clear: the festival of bureaucracy is a chance to trade workers with other kobold tribes in your attempts to build a more efficient government."),
				EffectsTable: map[FieldLabel]float64{
					BasePopulation: 20,
					Bureaucracy:    -1,
				},
				EnactionDesc: cardsim.MsgStr("Immigrant bureaucrats complain about being under-appreciated."),
				CanDo: func(t *TablePolicy, p *Player) bool {
					return p.Stats.Bureaucracy >= 2 && t.LastEnactedIdx != 3
				},
			},
			&TablePolicy{
				UnenactedDesc: cardsim.MsgStr(`Your Minister of Finance greets you exuberantly. "We've trimmed the wages of the bureaucracy beautifully, but maybe we can scout some outright volunteers.  Some tribes are absolute disasters, after all.`),
				EnactedDesc:   cardsim.MsgStr(`[current policy] It's hard to find volunteer workers at the festival, but your tribe is doing its best.`),
				EffectsTable: map[FieldLabel]float64{
					BasePopulation:   10,
					Bureaucracy:      -2,
					Rebellion:        1,
					Gullibility:      2,
					Authoritarianism: -1,
				},
				EnactionDesc: cardsim.MsgStr("The local bureaucracy is staffed by volunteer labor."),
				CanDo: func(t *TablePolicy, p *Player) bool {
					return p.Stats.Bureaucracy < 2 && t.LastEnactedIdx != 3
				},
			},
			&TablePolicy{
				UnenactedDesc: cardsim.MsgStr(`One of your non-bureaucrat friends has been in a foul temper.  "This festival is everything that's wrong with our society. Life isn't about filling out forms. We ought to snub this festival and outright fire a bunch of paper-pushers."`),
				EnactedDesc:   cardsim.MsgStr("Your tribe currently bans the Pan-Tribal Festival of Bureaucracy.  There will be no local celebration without a policy change."),
				EffectsTable: map[FieldLabel]float64{
					BasePopulation: 80,
					Bureaucracy:    4,
					Gullibility:    4,
				},
				EnactionDesc: cardsim.MsgStr("A wave of bureaucrats just emigrated along with kobolds incensed by the tribe's lack of respect for administration."),
				CanDo:        YesWeAlsoCan,
			},
			&VerbosePolicy{
				Default: &TablePolicy{
					UnenactedDesc: cardsim.MsgStr("Some kobolds will attend the festival on their own, and we may face desertions for our lack of interest."),
					EnactedDesc:   cardsim.MsgStr("Some kobolds will attend the festival on their own. No change is expected."),
					EffectsTable: map[FieldLabel]float64{
						BasePopulation: -20,
					},
					EnactionDesc: cardsim.MsgStr("A festival of bureaucracy lured away a few kobolds to other tribes."),
					CanDo:        YesWeAlsoCan,
				},
				Variants: []Policy{
					nil,
					&DisabledPolicy{cardsim.MsgStr("Neglecting the event would be less popular and more inefficient than our current policy.")},
					&DisabledPolicy{cardsim.MsgStr("Neglecting the event would be less popular and more inefficient than our current policy.")},
					&FuncPolicy{
						OptionTextFunc: func(p *Player) (cardsim.Message, error) {
							if p.Stats.Bureaucracy >= -3 {
								return cardsim.MsgStr("Permitting the festival will yield some immigration, but we'll be expected to rebuild our bureaucracy."), nil
							}
							return cardsim.MsgStr("Permitting the festival will yield some immigration."), nil
						},
						EnactFunc: func(p *Player) (cardsim.Message, error) {
							if p.Stats.Bureaucracy >= -3 {
								return cardsim.MsgStr("A festival of bureaucracy just saw the tribe's bureaucracy rebuilt."), ErrKeepMessage
							}
							return cardsim.MsgStr("A festival of bureaucracy brought in immigrants wondering at the tribe's unbureaucratic ways."), ErrKeepMessage
						},
					},
					nil, // remember, if using a BasicPolicy, this uses EnactedDesc
				},
			},
		}, // End of "Pan-Tribal Festival of Bureaucracy" policies
	}, // End of "Pan-Tribal Festival of Bureaucracy" card
	&SwitchingCard{ // Card 3
		Name:  cardsim.MsgStr("Two Kobolds in a Trenchcoat"),
		Desc:  cardsim.MsgStr("An inevitable concern of kobold tribes is the matter of trade.  Trade with other kobolds is straightforward, but overland caravans are unsafe.  Trade with surfacers is vital... but achieving it is difficult owing to anti-kobold sentiment."),
		After: ShuffleIntoBottomHalf,
		Policies: []Policy{
			&TablePolicy{
				UnenactedDesc: cardsim.MsgStr(`Speaking for the conservative opinion, one prospective merchant says, "We need illusions.  Our priority needs to be studying or trading to acquire or create spells or artifacts of disguising.  The high start-up costs will be balanced by subsequent free movement in a surface society that detests us."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Your merchants rely on magical disguises to avoid being identified as kobolds while doing business on the surface."),
				EffectsTable: map[FieldLabel]float64{
					Manufacturing: 3,
					Logistics:     4,
					Mining:        1,
					Alchemy:       1,
					Gadgetry:      1,
					Scavenging:    1,
					FoodSupply:    1,
					Secrecy:       5,
					Rebellion:     1,
					Greed:         1,
					Gullibility:   1,
				},
				EnactionDesc: cardsim.MsgStr("Nobody ever meets a kobold merchant."),
				CanDo:        YesWeAlsoCan,
			},
			&TablePolicy{
				UnenactedDesc: cardsim.MsgStr(`Brave but potentially headstrong, another prospective merchant has attended the meeting with the following plea.  "We must take head-on the risk of improving the status of kobolds!  Only by bravely attending the surface markets can we hope to achieve a true and lasting peace!"`),
				EnactedDesc:   cardsim.MsgStr(`[current policy] Your merchants represent the tribe's peaceful ideals by visiting the surface openly despite occasional casaulties.`),
				EffectsTable: map[FieldLabel]float64{
					BasePopulation:    -15,
					Manufacturing:     3,
					Logistics:         4,
					Mining:            2,
					Alchemy:           1,
					Gadgetry:          2,
					Hospitality:       1,
					Publishing:        1,
					ForeignRelExpense: 1,
					Militarism:        -1,
					Scavenging:        -1,
					Secrecy:           -10,
					ForeignRelations:  5,
					FoodSupply:        3,
					Greed:             1,
					Madness:           -1,
					Cruelty:           -1,
				},
				EnactionDesc: cardsim.MsgStr("The tribe formally plans for attrition among its merchants."),
				CanDo:        YesWeAlsoCan,
			},
			&TablePolicy{
				UnenactedDesc: cardsim.MsgStr(`A shady scavenger has offered to change careers and become a merchant.  Their proposal is, "Surfacers aren't all monolithic.  If we talk to the ones who are more greedy than prejudiced, we don't need magic or idealism.  We can get in contact with lots of people who'll buy lots of things from us, even things that might not have a market if we worked with 'good' merchants."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Your merchants work with the underworld of the surface, forging connections with the people who are ironically less likely to murder them."),
				EffectsTable: map[FieldLabel]float64{
					BasePopulation:   -5,
					Logistics:        1,
					Scavenging:       3,
					Alchemy:          2,
					Gadgetry:         2,
					Mining:           -1,
					Manufacturing:    -1,
					HiddenRelPenalty: 2, //High is bad on this hidden stat.
					Greed:            3,
					Gullibility:      -2,
				},
				EnactionDesc: cardsim.MsgStr("Kobold merchants are instantly suspected of black market connections."),
				CanDo:        YesWeAlsoCan,
			},
			&TablePolicy{
				UnenactedDesc: cardsim.MsgStr(`A mining forebold registered for the right to attend this meeting to say, "Surfacers can't be trusted and we shouldn't be supporting them with trade.  We need underground roads to ease trade with other kobolds.  It's a massive investment, but think of the reward: a world of underground civilizations supporting each other."`),
				EnactedDesc:   cardsim.MsgStr(`[currentpolicy] Your merchants have been directed to focus on trade with other kobolds, and your miners are perpetually tunnelling towards other kobold tribes in pursuit of the dream of a world of underground roads.`),
				EffectsTable: map[FieldLabel]float64{
					Mining:       5,
					Construction: 2,
					Logistics:    3,
					FoodSupply:   -1,
					Secrecy:      15,
					Gullibility:  -2,
				},
				EnactionDesc: cardsim.MsgStr("The vast network of caverns under the surface of the world is not a natural phenomenon."),
				CanDo:        YesWeAlsoCan,
			},
			&VerbosePolicy{
				Default: &BasicPolicy{
					UnenactedDesc: cardsim.MsgStr("Refusing an opportunity to expand trade is merely an opportunity cost.  It won't make conditions any better or worse."),
					EnactedDesc:   cardsim.MsgStr("Refusing an opportunity to expand trade is merely an opportunity cost.  It won't make conditions any better or worse."),
					Do: func(p *Player) (cardsim.Message, error) {
						return cardsim.MsgStr("Kobold merchants are known for their talent at standing on each others' shoulders."), nil
					},
					Undo: func(p *Player) error {
						return nil
					},
					CanDo: YesWeCan,
				},
				Variants: []Policy{
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Rejecting the illusion-based merchantry will cost us a great deal in trade and surface food, but we can certainly do it."),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Rejecting our idealistic approach to surface trade will save a few lives directly, but consider how much we need the food we buy!"),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("The surfacers' governments would certainly prefer us to abandon our underworld connections in their cities.  Do we care about that?  We'd be giving up some excellent profits."),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Some of the miners would be heartbroken by abandoning the dream of underground roads, but the tax savings would be significant.  Reducing our trade focus on other kobolds does however carry some risk."),
					},
				},
			},
		}, // End of "Two Kobolds in a Trenchcoat" policies
	}, // End of "Two Kobolds in a Trenchcoat" card
	&SwitchingCard{ // Card 4
		Name:  cardsim.MsgStr("A Recipe for Stewed Kobold"),
		Desc:  cardsim.MsgStr("Nobody would ever say a kobold smells bad, but the constant burrowing, manufacturing, and metallurgy that is common to kobold life is still a recipe for tense muscles and filthy scales.  A slate of proposals have come through to address this issue."),
		After: ShuffleIntoBottomHalf,
		Policies: []Policy{
			&TablePolicy{
				UnenactedDesc: cardsim.MsgStr(`A calm and cheerful scribe says, "We should have public baths!  We have more problems with flooding than drought in the deep underground, so we've got plenty of water.  We just need to channel it.  We could create a hub of social life while improving the health of everybody!"`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Public bathing is a staple social policy in the mines and warrens of your tribe."),
				EffectsTable: map[FieldLabel]float64{
					Construction: 2,
					Welfare:      1,
					Healthcare:   1,
					ParksExpense: 4,
					Hospitality:  1,
					Madness:      -1,
					Cruelty:      -1,
					Greed:        -1,
				},
				EnactionDesc: cardsim.MsgStr("The company of others makes cold water tolerable."),
				CanDo:        YesWeAlsoCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`Your Minister of Finance is scandalized.  "A free service?  And such an expensive one to construct?  No, no, no.  The baths must pull their weight in the budget if they're ot be made at all.  We must set an entry fee."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Elite bathhouses serve paying customers in your largest sites."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.Construction += 2
					p.Stats.Hospitality += 3
					p.Stats.ParksExpense += 2
					return cardsim.MsgStr("A dirty body is the mark of the lower classes."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.Construction -= 2
					p.Stats.Hospitality -= 3
					p.Stats.ParksExpense -= 2
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`Your head diplomat chimes in with, "If you want to make the service self-sustaining, build a bath in a shallow cave and invite the surfacers in for a fee.  Of course, we'll be giving up some of our secrecy, but it'll bring in foreign exchange to power our industries."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Conservative kobolds are scandalized: not only has the tribe bathhouses, it has near-surface bathhouses for surfacers to visit."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.Construction += 2
					p.Stats.Hospitality += 4
					p.Stats.Manufacturing += 1
					p.Stats.ParksExpense += 3
					p.Stats.FoodSupply += 1
					p.Stats.ForeignRelExpense += 1
					p.Stats.ForeignRelations += 1
					p.Stats.HiddenRelPenalty -= -2
					p.Stats.Secrecy -= 10
					p.Stats.Cruelty -= 1
					return cardsim.MsgStr("Surfacers stink less in the tribe's vicinity."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.Construction -= 2
					p.Stats.Hospitality -= 3
					p.Stats.Manufacturing -= 1
					p.Stats.ParksExpense -= 3
					p.Stats.FoodSupply -= 1
					p.Stats.ForeignRelExpense -= 1
					p.Stats.ForeignRelations -= 1
					p.Stats.HiddenRelPenalty += 2
					p.Stats.Secrecy += 10
					p.Stats.Cruelty += 1
					return nil
				},
				CanDo: YesWeCan,
			},
			&VerbosePolicy{
				Default: &BasicPolicy{
					UnenactedDesc: cardsim.MsgStr("Bathhouses are a big project that would displace other things in the city center.  You could use the space for housing and services instead."),
					EnactedDesc:   cardsim.MsgStr("When is the right time to embark on building public baths?  You can hew close to skeptics instead."),
					Do: func(p *Player) (cardsim.Message, error) {
						p.Stats.BasePopulation += 5
						p.Stats.Gullibility -= 1
						return cardsim.MsgStr("Opponents of public bathing won a recent political contest."), nil
					},
					Undo: func(p *Player) error {
						p.Stats.BasePopulation -= 5
						p.Stats.Gullibility += 1
						return nil
					},
					CanDo: YesWeCan,
				},
			},
		}, // End of "A Recipe for Stewed Kobold" policies
	}, // End of "A Recipe for Stewed Kobold" card
	&SwitchingCard{ // Card 5
		Name:  cardsim.MsgStr("Raid on Surface Proposed"),
		Desc:  cardsim.MsgStr("Resources underground are perpetually tight.  Even metallurgy is hard, because fuel is scarce.  You can rely on neither field nor forest.  The scavengers brave the surface regularly to beg, borrow, or steal the resources necessary to your society, but your war planners want to secure resources more aggressively."),
		After: ShuffleIntoBottomHalf,
		IsValid: func(c Card, p *Player) bool {
			return p.Stats.Militarism > 0
		},
		Policies: []Policy{
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`A scavenger clad in sturdy clothes says, "We need to secure a section of forests on the surface.  The surfacers strip too many of the forests bare; if we dispatch patrols ready to fight we can keep them from assarting the forest for their endlessly growing farm communities."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] The war department maintains your meagre conquest of a stretch of forest on the surface."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation -= 20
					p.Stats.Forestry += 3
					p.Stats.Militarism += 0.01
					p.Stats.FoodSupply += 3
					p.Stats.Secrecy -= 10
					p.Stats.ForeignRelations -= 2
					p.Stats.Madness -= 1
					p.Stats.Gullibility -= 1
					return cardsim.MsgStr("A bunch of lumberjacks just disappeared in a forest."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.BasePopulation += 20
					p.Stats.Forestry -= 3
					p.Stats.Militarism -= 1
					p.Stats.FoodSupply -= 5
					p.Stats.Secrecy += 10
					p.Stats.ForeignRelations += 2
					p.Stats.Madness += 1
					p.Stats.Gullibility += 1
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`A very scrawny warrior waves a spear over their head and says, "That's not going far enough!  We need to seize farmland of our own!  Come on, we shouldn't have to eat cave lichen while the surfacers eat roast pig!"`),
				EnactedDesc:   cardsim.MsgStr("[current policy] The 'ghost farms' in this region are worked by night as kobolds sparing their eyes avoid doing farmwork in daylight."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation -= 40
					p.Stats.Agriculture += 1
					p.Stats.Militarism += 2
					p.Stats.FoodSupply += 6
					p.Stats.Secrecy -= 20
					p.Stats.ForeignRelations -= 4
					p.Stats.Cruelty += 1
					return cardsim.MsgStr("Some farmers fight like five kobolds, but few fight like forty."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.BasePopulation += 40
					p.Stats.Agriculture -= 1
					p.Stats.Militarism -= 2
					p.Stats.FoodSupply -= 6
					p.Stats.Secrecy += 20
					p.Stats.ForeignRelations += 4
					p.Stats.Cruelty -= 1
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`A warrior kobold of quiet intensity says, "We shouldn't try to hold terrain on the surface.  We'll give ourselves away to surfacers who otherwise can't pinpoint us.  Remember that we can't stand against their armies.  What we can do without violating secrecy is focus on banditry.  We've mapped activity in our area; it's time to go in for a harvest of our own."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Your warriors target caravans for intimidation and larceny."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation -= 10
					p.Stats.Scavenging += 2
					p.Stats.Militarism += 1
					p.Stats.FoodSupply += 1
					p.Stats.Secrecy -= 5
					p.Stats.HiddenRelPenalty += 5
					p.Stats.Rebellion += 2
					p.Stats.Cruelty += 4
					p.Stats.Greed += 2
					p.Stats.Gullibility -= 1
					return cardsim.MsgStr("Some merchants are even cordial as they pay off kobold bandits."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.BasePopulation += 10
					p.Stats.Scavenging -= 2
					p.Stats.Militarism -= 1
					p.Stats.FoodSupply -= 1
					p.Stats.Secrecy += 5
					p.Stats.HiddenRelPenalty -= 5
					p.Stats.Rebellion -= 2
					p.Stats.Cruelty -= 4
					p.Stats.Greed -= 2
					p.Stats.Gullibility += 1
					return nil
				},
				CanDo: YesWeCan,
			},
			&VerbosePolicy{
				Default: &BasicPolicy{
					UnenactedDesc: cardsim.MsgStr("Rejecting militarism will set back the war department, but hunger will persist."),
					EnactedDesc:   cardsim.MsgStr("[current policy] The war department has been rebuked for its aggression."),
					Do: func(p *Player) (cardsim.Message, error) {
						p.Stats.Secrecy += 1
						p.Stats.Militarism -= 1
						p.Stats.HiddenRelPenalty -= 1
						p.Stats.Cruelty -= 1
						p.Stats.Madness -= 1
						p.Stats.Gullibility -= 1
						return cardsim.MsgStr("Some of the warriors have had their fervor redirected into economic pursuits."), nil
					},
					Undo: func(p *Player) error {
						p.Stats.Secrecy -= 1
						p.Stats.Militarism += 1
						p.Stats.HiddenRelPenalty += 1
						p.Stats.Cruelty += 1
						p.Stats.Madness += 1
						p.Stats.Gullibility += 1
						return nil
					},
					CanDo: YesWeCan,
				},
			},
		}, // End of "Raid on Surface Proposed" policies
	}, // End of "Raid on Surface Proposed" card
	&SwitchingCard{ // Card 6
		Name:  cardsim.MsgStr("Book Publishing Threat to Secrecy?"),
		Desc:  cardsim.MsgStr("Concerns have been raised about one of the categories of income that your tribe relies upon: books.  To a lesser extent, art in general.  Some artifacts, especially books, have the potential to give away details of your peoples' lives that help hostile powers locate your tribe."),
		After: ShuffleIntoBottomHalf,
		IsValid: func(c Card, p *Player) bool {
			return p.Stats.Publishing > 0 && p.Stats.ForeignRelations < 0
		},
		Policies: []Policy{
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`The warrior who brought this to your attention stands at attention as they say, "The risk of discovery is an existential risk!  Everything that makes us discoverable increases the intensity of conflict around our warrens, draining lives from our people!  It is imperative that all respect our code of silence!"`),
				EnactedDesc:   cardsim.MsgStr("[current policy] The tribe's warriors enforce a code of silence at spearpoint."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.Secrecy += 3
					p.Stats.Publishing -= 5
					p.Stats.Education -= 1
					p.Stats.Madness += 2
					p.Stats.Authoritarianism += 2
					p.Stats.Gullibility -= 1
					return cardsim.MsgStr("No history records the sobbing of kobold scribes."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.Secrecy -= 3
					p.Stats.Publishing += 5
					p.Stats.Education += 1
					p.Stats.Madness -= 2
					p.Stats.Authoritarianism += 2
					p.Stats.Gullibility -= 1
					return nil
				},
				CanDo: func(b *BasicPolicy, p *Player) bool {
					return p.Stats.Militarism > 0
				},
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`"No!  Never!  Er, maybe?" asks a dithering scribe, clutching a book worriedly to their chest.  "Don't give it to the warriors!  Can we set up an office of censorship to read everything we publish and send it back for edits if it would reveal anything about our location?  We don't have to stop publishing; our traders buy food with foreign currencies you know!"`),
				EnactedDesc:   cardsim.MsgStr("[current policy] The bureaucracy includes an office of censorship that reads all writings produced for sale to ensure that nothing is revealed about the location of any living kobolds."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.Secrecy += 1
					p.Stats.Publishing -= 1
					p.Stats.Bureaucracy += 1
					p.Stats.Authoritarianism += 2
					return cardsim.MsgStr("The censors are the most well-read kobolds in the tribe."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.Secrecy -= 1
					p.Stats.Publishing += 1
					p.Stats.Bureaucracy -= 1
					p.Stats.Authoritarianism -= 2
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`Your Minister of Education wrings his claws sadly.  "I know it'll be a monumental expense in paper and ink, but we need to encourage the writing of diaries.  Our secrecy is already flawed; there are already attacks against us.  Maybe our attackers will find diaries and understand that we aren't just thieves hiding under the earth."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Even though recovered diaries point back to your outposts, your kobolds are encouraged to carry around diaries and record thoughts from their own lives into them."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.Secrecy -= 1
					p.Stats.Publishing += 2
					p.Stats.Education += 3
					p.Stats.Propaganda += 1
					p.Stats.HiddenRelPenalty -= 1
					p.Stats.Rebellion += 1
					p.Stats.Madness -= 1
					p.Stats.Cruelty -= 2
					p.Stats.Greed -= 1
					p.Stats.Gullibility -= 1
					return cardsim.MsgStr("Heartless surfacers burn recovered kobold diaries."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.Secrecy += 1
					p.Stats.Publishing -= 2
					p.Stats.Education -= 3
					p.Stats.Propaganda -= 1
					p.Stats.HiddenRelPenalty += 1
					p.Stats.Rebellion -= 1
					p.Stats.Madness += 1
					p.Stats.Cruelty += 2
					p.Stats.Greed += 1
					p.Stats.Gullibility += 1
					return nil
				},
				CanDo: func(b *BasicPolicy, p *Player) bool {
					return p.Stats.Secrecy < 1
				},
			},
			&VerbosePolicy{
				Default: &BasicPolicy{
					UnenactedDesc: cardsim.MsgStr("Although promoting diaries would do even more for literacy, rejecting this will still inspire celebrations among the authors of your tribe."),
					EnactedDesc:   cardsim.MsgStr("The dangers posed by publishing information from your tribe can be denied without changes in policy."),
					Do: func(p *Player) (cardsim.Message, error) {
						p.Stats.Publishing += 1
						return cardsim.MsgStr("Kobold-hating adventurers know to be well-read."), nil
					},
					Undo: func(p *Player) error {
						p.Stats.Publishing -= 1
						return nil
					},
					CanDo: YesWeCan,
				},
				Variants: []Policy{
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Your publishing industry is struggling under harsh restrictions and would soar if relieved."),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("The censorship office spends tax money to crimp tax income.  It has opponents, though they stay quiet."),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Rescinding the diary initiative would ding literacy rates, but it should save on taxes."),
					},
				},
			},
		}, // End of "Book Publishing Threat to Security?" policies"
	}, // End of "Book Publishing Threat to Security?" card
	&SwitchingCard{ // Card 7
		Name:  cardsim.MsgStr("The Eyes that Break the Ground"),
		Desc:  cardsim.MsgStr("Some of our miners have recently been afflicted with shared hallucinations.  They report feelings of being watched in dark areas - which, thanks to kobold darkvision, is nearly everywhere - as well as seeing black blotches covered in eyes on various surfaces.  They're refusing to continue work."),
		After: ShuffleIntoBottomHalf,
		Policies: []Policy{
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`A friend of one of the afflicted managed to get onto your meeting schedule to say, "We work our miners hard.  We need to give them more breaks.  We need to fund more investments into healthcare, too.  We can set our alchemists to work brewing potions that should help."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Afflicted miners are being dosed with soothing alchemical teas."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.Mining -= 1
					p.Stats.Alchemy += 2
					p.Stats.Healthcare += 1 // TODO:  Implement population boost from Healthcare investment.  Maybe 1000x HealthcareInvestment, so that each 0.01 Healthcare Investment is a bonus of 10 kobolds to the population?
					p.Stats.Cruelty -= 1
					p.Stats.Authoritarianism -= 2
					return cardsim.MsgStr("Calming alchemical potions are displacing raw material sales in local markets."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.Mining += 1
					p.Stats.Alchemy -= 2
					p.Stats.Healthcare -= 1
					p.Stats.Cruelty += 1
					p.Stats.Authoritarianism += 2
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`Your chief economic planner regards the report with surprise and disgust.  "This is just an excuse for slacking!  Send them back into the mines and hire guards to make sure they double production!  And if they see any more eyes in the dark, tell 'em to shatter 'em with detonation charges!"`),
				EnactedDesc:   cardsim.MsgStr("[current policy] The mines are taut as crazy miners with explosives work under the oversight of armed guards."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation -= 10
					p.Stats.Mining += 3
					p.Stats.Gadgetry += 1
					p.Stats.Militarism += 1
					p.Stats.Cruelty += 1
					p.Stats.Rebellion += 1
					p.Stats.Madness += 4
					p.Stats.Authoritarianism -= 2
					return cardsim.MsgStr("Miners are known for their enthusiasm for explosives."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.Mining -= 3
					p.Stats.Gadgetry -= 1
					p.Stats.Militarism -= 1
					p.Stats.Cruelty += 1
					p.Stats.Rebellion -= 1
					p.Stats.Madness -= 4
					p.Stats.Authoritarianism += 2
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`The head of your Ministry of Soothsaying, Shamanism, and Otherworldly Affairs has reacted with unsettling enthusiasm.  "Shared hallucinations?  Of eyes in the dark?  This is an opportunity!  We just need to train the afflicted into new spellcasters.  We could learn the kind of secrets that shatter minds!"`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Mine policy is to watch for this symptom and trial the afflicted in planar summoning."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation -= 20
					p.Stats.Mining -= 1
					p.Stats.PlanarConnections += 3
					p.Stats.ResearchSubs += 1
					p.Stats.Madness += 4
					p.Stats.Authoritarianism -= 2
					return cardsim.MsgStr("The tribe is infamous for producing crazed magi."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.BasePopulation += 20
					p.Stats.Mining += 1
					p.Stats.PlanarConnections -= 3
					p.Stats.ResearchSubs -= 1
					p.Stats.Madness -= 4
					p.Stats.Authoritarianism += 2
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`The manager of one of the affected signed the right papers to get into this meeting.  Regarding you coldly, they say, "They're slacking, and it's not right to permit anything to change.  We don't need soothing alchemicals, we don't need new guards, adding explosives to the mix is just chaotic, and recruiting crazies as spellcasters is insane itself.  Trust in the miners to enforce discipline amongst each other.  We don't permit anyone to hold up production."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] The miners are dealing with laggard elements on their own."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation -= 20
					p.Stats.Mining += 3
					p.Stats.Rebellion -= 3
					p.Stats.Madness += 1
					p.Stats.Cruelty += 2
					p.Stats.Authoritarianism += 1
					return cardsim.MsgStr("Sufficient misery unmakes people."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.BasePopulation += 20
					p.Stats.Mining -= 3
					p.Stats.Rebellion += 3
					p.Stats.Madness -= 1
					p.Stats.Cruelty -= 2
					p.Stats.Authoritarianism -= 1
					return nil
				},
				CanDo: YesWeCan,
			},
			&VerbosePolicy{
				Default: &BasicPolicy{
					UnenactedDesc: cardsim.MsgStr("Maybe we can just work around the afflicted.  Let them rest and find other employment."),
					EnactedDesc:   cardsim.MsgStr("[current policy] We're encouraging the afflicted to rest and find other employment."),
					Do: func(p *Player) (cardsim.Message, error) {
						p.Stats.Mining -= 1
						p.Stats.Cruelty -= 1
						return cardsim.MsgStr("Mining is just too strenuous for some kobolds."), nil
					},
					Undo: func(p *Player) error {
						p.Stats.Mining += 1
						p.Stats.Cruelty += 1
						return nil
					},
					CanDo: YesWeCan,
				},
				Variants: []Policy{
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Rescinding the healthcare subsidy might ding our population, but it shouldn't ding our compassion.  We're being very gentle with these people."),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Withdrawing explosives access from the suffering may be a life-saving action..."),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Maybe we should close the door on these particular otherworldly contacts."),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("The miners' culture is harsh!  There's an argument here for protecting the suffering."),
					},
					nil,
				},
			},
		}, // end of "The Eyes that Break the Ground" policies
	}, // end of "The Eyes that Break the Ground" card
	&SwitchingCard{ // Card 8
		Name:  cardsim.MsgStr("Planar Targeting"),
		Desc:  cardsim.MsgStr("Now that you've established a planar harvesting industry and have begun to tap into the economic potential of other planes of existence, your magi are seeking guidance as to where they should direct their efforts."),
		After: ShuffleIntoBottomHalf,
		IsValid: func(c Card, p *Player) bool {
			return p.Stats.PlanarConnections > 0
		},
		Policies: []Policy{
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`A calm, graceful, and scrawny mage with a big floppy hat has presented an entry-level option.  "We should be tapping into one of the basic energy planes.  While somewhat lacking in ambition and creating a risk of immolating students, the risks are less than many extraplanar contacts.  This option also doesn't require an extensive infrastructure to begin."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Your colonies have established contact with energy planes to power spellcasting and potioneering."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation -= 50
					p.Stats.PlanarConnections += 3
					p.Stats.Alchemy += 1
					p.Stats.Rebellion -= 1
					p.Stats.Madness += 1
					p.Stats.Gullibility -= 1
					return cardsim.MsgStr("Surviving mage-students are really excited about their new curriculum."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.BasePopulation += 50
					p.Stats.PlanarConnections -= 3
					p.Stats.Alchemy -= 1
					p.Stats.Rebellion += 1
					p.Stats.Madness -= 1
					p.Stats.Gullibility -= 1
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`A questionably sane mage wearing a robe of eyes insists, "We should tap the elder realms!  It is the fastest way to accelerate our planar harvesting!  Tapping into them requires little more than a willingness to try, and the scraps taken from the societies in those realms yield technology beyond our wildest dreams!  Don't flinch from the hazard; it is a step towards world conquest!"`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Your tribe is locked in conflict with the lesser minions of elder horrors as it seeks to steal power from the mindbreaking realms."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation -= 250
					p.Stats.PlanarConnections += 10
					p.Stats.Alchemy += 3
					p.Stats.Gadgetry += 3
					p.Stats.Militarism += 5
					p.Stats.ResearchSubs += 1
					p.Stats.HiddenRelPenalty += 2
					p.Stats.Rebellion += 1
					p.Stats.Madness += 1
					p.Stats.Cruelty += 2
					p.Stats.Greed += 3
					p.Stats.Gullibility -= 2
					p.Stats.Authoritarianism -= 1
					return cardsim.MsgStr("Several caves have been abandoned to an infestation of eldritch horrors."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.BasePopulation += 250
					p.Stats.PlanarConnections -= 10
					p.Stats.Alchemy -= 3
					p.Stats.Gadgetry -= 3
					p.Stats.Militarism -= 5
					p.Stats.ResearchSubs -= 0.01
					p.Stats.HiddenRelPenalty -= 2
					p.Stats.Rebellion -= 1
					p.Stats.Madness -= 1
					p.Stats.Cruelty -= 2
					p.Stats.Greed -= 3
					p.Stats.Gullibility += 2
					p.Stats.Authoritarianism += 1
					return nil
				},
				CanDo: func(b *BasicPolicy, p *Player) bool {
					return p.Stats.PlanarConnections > 2
				},
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`A stout kobold in a plain robe showed up to say, "Beware!  Every planar connection leaks strange energies into the world.  The safe connections, once we've the skill to make them, are to the well-ordered and benevolent realms.  They have alchemical wonders and great wisdom, but moreover the energies that leak off the connection will make society more well-ordered rather than less."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Your planar explorers have been directed to the planes of law in hopes of finding the secret of a well-governed society."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation += 20
					p.Stats.PlanarConnections += 3
					p.Stats.Alchemy += 4
					p.Stats.Publishing += 2
					p.Stats.Hospitality += 1
					p.Stats.Gadgetry += 1
					p.Stats.ParksExpense += 1
					p.Stats.HiddenRelPenalty -= 1 //High is bad on this stat.
					p.Stats.Rebellion -= 4
					p.Stats.Madness -= 2
					p.Stats.Cruelty -= 5
					p.Stats.Greed -= 3
					p.Stats.Gullibility += 2
					p.Stats.Authoritarianism -= 2
					// TODO:  This will affect crime and corruption rates.
					return cardsim.MsgStr("Planar explorers find their work boring."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.BasePopulation -= 20
					p.Stats.PlanarConnections -= 3
					p.Stats.Alchemy -= 4
					p.Stats.Publishing -= 2
					p.Stats.Hospitality -= 1
					p.Stats.Gadgetry -= 1
					p.Stats.ParksExpense -= 1
					p.Stats.HiddenRelPenalty += 1
					p.Stats.Rebellion += 4
					p.Stats.Madness += 2
					p.Stats.Cruelty += 5
					p.Stats.Greed += 3
					p.Stats.Gullibility -= 2
					p.Stats.Authoritarianism += 2
					return nil
				},
				CanDo: func(b *BasicPolicy, p *Player) bool {
					return p.Stats.PlanarConnections > 11
				},
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`Your Minister of Planar Studies crashed the meeting dressed like a wealthy scavenger.  "Skip these esoteric planes!  We want alternate material planes so we can steal stuff that's guaranteed to teach us more about how THIS reality works.  If we start hunting, maybe we can even hit the real goldmine: a graveyard world whose gadgetry is post-ownership.  Besides, uh...  Meat is meat, mostly.  We can hunt on other worlds if we stick to the ones that work like our own."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Your planar harvesters try to scan the multiverse for scavenging targets."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation -= 4
					p.Stats.Alchemy += 1
					p.Stats.Gadgetry += 5
					p.Stats.Scavenging += 5
					p.Stats.Publishing += 1
					p.Stats.Madness -= 1
					p.Stats.FoodSupply += 2
					p.Stats.Greed += 1
					return cardsim.MsgStr("Planes without kobolds tell stories of reptillian infiltrators."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.BasePopulation += 4
					p.Stats.Alchemy -= 1
					p.Stats.Gadgetry -= 5
					p.Stats.Scavenging -= 5
					p.Stats.Publishing -= 1
					p.Stats.Madness += 1
					p.Stats.FoodSupply -= 2
					p.Stats.Greed -= 1
					return nil
				},
				CanDo: func(b *BasicPolicy, p *Player) bool {
					return p.Stats.PlanarConnections > 11
				},
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`The mage in the robe of eyes is in a celebratory mood, pouring glasses for anyone who'll take them from a bottle of some bluish-black liquid that you're pretty sure is dangerous.  "Our planar harvesting potential has grown magnificently!  If we target deeper into the elder planes, they'll... okay, they won't exactly fear us, but we can start taking some real treasures from them!  Great spells!  Exotic reagents!  Unique treasures!  Let's lean into the hazard!`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Your tribe is sacrificing safety and sanity in thievery attempts that only serve the plans of the elder gods."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation -= 350
					p.Stats.PlanarConnections += 15
					p.Stats.Alchemy += 4
					p.Stats.Gadgetry += 5
					p.Stats.Militarism += 5
					p.Stats.ResearchSubs += 1
					p.Stats.ForeignRelations -= 5
					p.Stats.HiddenRelPenalty += 5
					p.Stats.Rebellion += 4
					p.Stats.Madness += 20
					p.Stats.Cruelty += 8
					p.Stats.Greed += 10
					p.Stats.Gullibility -= 5
					p.Stats.Authoritarianism -= 2
					return cardsim.MsgStr("Nobody dares touch the treasures in the tribal vault."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.BasePopulation += 350
					p.Stats.PlanarConnections -= 15
					p.Stats.Alchemy -= 4
					p.Stats.Gadgetry -= 5
					p.Stats.Militarism -= 5
					p.Stats.ResearchSubs -= 1
					p.Stats.ForeignRelations += 5
					p.Stats.HiddenRelPenalty -= 5
					p.Stats.Rebellion -= 4
					p.Stats.Madness -= 20
					p.Stats.Cruelty -= 8
					p.Stats.Greed -= 10
					p.Stats.Gullibility += 5
					p.Stats.Authoritarianism += 2
					return nil
				},
				CanDo: func(b *BasicPolicy, p *Player) bool {
					return p.Stats.PlanarConnections >= 20
				},
			},
			&VerbosePolicy{
				Default: &BasicPolicy{
					UnenactedDesc: cardsim.MsgStr("Rejecting the safety risks of extraplanar travels will call your entire planar harvesting industry into question, but it might be the safest option."),
					EnactedDesc:   cardsim.MsgStr("Persisting in your rejection of planar targeting will change nothing."),
					Do: func(p *Player) (cardsim.Message, error) {
						p.Stats.BasePopulation += 40
						p.Stats.PlanarConnections -= 1
						p.Stats.Greed -= 1
						p.Stats.Authoritarianism -= 1
						return cardsim.MsgStr("The tribe recently gained a few immigrants reassured by the lack of planar portals."), nil
					},
					Undo: func(p *Player) error {
						p.Stats.BasePopulation -= 40
						p.Stats.PlanarConnections += 1
						p.Stats.Greed += 1
						p.Stats.Authoritarianism += 1
						return nil
					},
					CanDo: YesWeCan,
				},
				Variants: []Policy{
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("The energy planes are popular among students who survive accessing them.  Student safety would benefit from rejecting planar targeting, but your economy would take a blow."),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("People are begging you to close the eldritch portals.  They'll take anything else.  Literally anything else."),
					},
					&DisabledPolicy{}, // There's no closing the plane to a portal of law save by choosing something else.
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("There is some opposition to stealing from the multiverse, decrying the raw greed involved."),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("People are begging you to close the eldritch portals.  They'll take anything else.  Literally anything else."),
					},
				},
			},
		}, // end of "Planar Targeting" policies
	}, // end of "Planar Targeting" card
	&SwitchingCard{ // Card 9
		Name:  cardsim.MsgStr("Strategic Sweets"),
		Desc:  cardsim.MsgStr("Leading a starving kobold tribe can be pretty dreary.  Rats, weeds, and tea made from moss...  Even the VIPs are scrawny on this fare."),
		After: ShuffleIntoBottomHalf,
		IsValid: func(c Card, p *Player) bool {
			return p.Stats.FoodSupply < 30
		},
		Policies: []Policy{
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`A rail-thin minister hoists their claws at the roof in frustration as they say, "I can't take it anymore!  I'm not meant to be this skinny!  If it takes a whole shipment of ore to buy us a single cake, that's just the price of leadership!"`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Funding sweet treats for leadership is considered an economic priority."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.FoodSupply += 1
					p.Stats.ForeignRelations += 1
					p.Stats.Rebellion += 1
					p.Stats.Authoritarianism += 1
					// TODO:  Make this increase corruption.
					return cardsim.MsgStr("High food prices are fitting kobolds into the economy."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.FoodSupply -= 1
					p.Stats.ForeignRelations -= 1
					p.Stats.Rebellion -= 1
					p.Stats.Authoritarianism -= 1
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`A loyal mining foreman looks at the minister with crossed arms.  "We definitely need more food, but we absolutely shouldn't set the example of feasting while others starve.  We need to expand the Quality of Life budget and declare a sweets ration.  Let them eat cake!"`),
				EnactedDesc:   cardsim.MsgStr("[current policy] A sweets ration helps kobolds face the challenge of hard labour."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.Welfare += 4
					p.Stats.FoodSupply += 2
					p.Stats.Cruelty -= 1
					p.Stats.Rebellion -= 1
					p.Stats.Gullibility += 1
					p.Stats.Greed -= 1
					// TODO:  Implement QoL functions.
					return cardsim.MsgStr("The government is proud to secure sweets for the public."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.Welfare -= 4
					p.Stats.FoodSupply -= 2
					p.Stats.Cruelty += 1
					p.Stats.Rebellion += 1
					p.Stats.Gullibility -= 1
					p.Stats.Greed += 1
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`One of your tribe's few stout kobolds brings the issue up in the cafeteria.  "I've heard rumour that some kobolds are begging for sweets.  We need to take a stand against that and squelch it early!  Fund nutrition research to prove what's truly healthy for kobolds!"  They look at you sidelong.  "And, uh.  Hire me for the research.  I want a food subsidy that I can call a long-term benefit to the tribe."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Your tribe is paying some kobolds to track how food affects health.  Current consensus: your tribe is underfed."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.ResearchSubs += 1
					p.Stats.Publishing += 1
					p.Stats.FoodSupply += 1
					return cardsim.MsgStr("Eating lichen soup is remarkably thinning."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.ResearchSubs -= 1
					p.Stats.Publishing -= 1
					p.Stats.FoodSupply -= 1
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr("Perhaps subsidies are the wrong approach to food procurement."),
				EnactedDesc:   cardsim.MsgStr("Perhaps subsidies are the wrong approach to food procurement."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation -= 20
					return cardsim.MsgStr("A few kobolds have emigrated in fear of famine."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.BasePopulation += 20
					return nil
				},
				CanDo: YesWeCan,
			},
		},
	}, // end of "Strategic Sweets" card
	&SwitchingCard{ // Card 10
		Name:  cardsim.MsgStr("The Foremost Deity"),
		Desc:  cardsim.MsgStr("Which of the kobold deities should be regarded as the patron of your tribe?"),
		After: ShuffleIntoBottomHalf,
		Policies: []Policy{
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`"Kobolds were meant to serve dragons!" insists one of your more sycophantic kobolds.  "Instead of having a patron deity, we should find a dragon who we can swear undying loyalty to, assuring them that there are no higher deities in our lives than they.  This is one of the most cost-effective ways to get a dragon, and the total loyalty of a kobold tribe often appeals to very powerful dragons who stand to gain a lot of prominence among dragons from being deified.`),
				EnactedDesc:   cardsim.MsgStr("[current policy] The tribe is venerating a powerful dragon as the tribe's patron deity."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.DragonCount += 1
					p.Stats.Finance += 2
					p.Stats.Hospitality += 1
					p.Stats.Militarism += 1
					p.Stats.Authoritarianism += 1
					p.Stats.Rebellion -= 2
					return cardsim.MsgStr("The tribe's new dragon tyrant is settling in nicely."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.DragonCount -= 1
					p.Stats.Finance -= 2
					p.Stats.Hospitality -= 1
					p.Stats.Militarism -= 1
					p.Stats.Authoritarianism -= 1
					p.Stats.Rebellion += 2
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`A paragon of your tribe raises their hands and says, "The only patron deity for any lawful tribe is Izkren.  The honored Queen of the Gods, Izkren stands for the striving towards paradise in life and after it.  To exalt another god over her is to stand in rebellion against the proper way of things and invite in chaos."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Izkren, Queen of the Gods, has been installed as the foremost deity of the tribe."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.Faith += 3
					p.Stats.Publishing += 1
					p.Stats.Hospitality += 1
					p.Stats.Construction += 1
					p.Stats.Authoritarianism += 2
					p.Stats.Rebellion -= 4
					p.Stats.Madness -= 1
					p.Stats.Greed -= 1
					return cardsim.MsgStr("Izkren is silent, but surely her approval can only bring your tribe to glory."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.Faith -= 3
					p.Stats.Publishing -= 1
					p.Stats.Hospitality -= 1
					p.Stats.Construction -= 1
					p.Stats.Authoritarianism -= 2
					p.Stats.Rebellion += 4
					p.Stats.Madness += 1
					p.Stats.Greed += 1
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`A wise old kobold bows and avows, "Although it is a heterodox perspective, there are tribes that exalt the tinkering sage Sobol over all other gods.  This practice puts wisdom and technical skill into an exalted position, bringing philosophers and engineers alike into the faith.  Sobol's worship is sometimes derided as crypto-atheistic, but I assure you there are sincere advocates as well."`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Sobol, the Wise Tinkerer, is considered the highest deity among the tribe."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation += 50
					p.Stats.Faith += 1
					p.Stats.Education += 2
					p.Stats.ResearchSubs += 1
					p.Stats.Manufacturing += 1
					p.Stats.Construction += 1
					p.Stats.Publishing += 2
					p.Stats.Gadgetry += 2
					p.Stats.Alchemy += 1
					p.Stats.Madness -= 1
					return cardsim.MsgStr("The number of kobolds the tribe can support increases with its technical sophistication."), nil
				},
				Undo: func(p *Player) error {
					p.Stats.BasePopulation -= 50
					p.Stats.Faith -= 1
					p.Stats.Education -= 2
					p.Stats.ResearchSubs -= 1
					p.Stats.Manufacturing -= 1
					p.Stats.Construction -= 1
					p.Stats.Publishing -= 2
					p.Stats.Gadgetry -= 2
					p.Stats.Alchemy -= 1
					p.Stats.Madness += 1
					return nil
				},
				CanDo: YesWeCan,
			},
			&BasicPolicy{
				UnenactedDesc: cardsim.MsgStr(`"Ektani!" cries a youthful kobold in a white robe.  "The goddess of life!  Some of her great saints are immortal!  If you install Ektani as our highest god, we'll gain healing magics immediately.  People will survive sickness and injury.  They'll flock to us from plague-stricken tribes.  And our healthcare professionals will be greatly exalted!"`),
				EnactedDesc:   cardsim.MsgStr("[current policy] Ektani, the exalted healer, is considered to be the tribe's rightful patron."),
				Do: func(p *Player) (cardsim.Message, error) {
					p.Stats.BasePopulation += 1
					p.Stats.Faith += 3
					p.Stats.Healthcare += 2
					p.Stats.Education += 1
					p.Stats.Secrecy -= 1
					p.Stats.Cruelty -= 1
					p.Stats.Madness -= 1
					p.Stats.FoodSupply -= 10
					return cardsim.MsgStr("Ektani's support plunges death rates and childhood mortality while causing immigration to surge.  Can you feed everyone?"), nil
				},
				Undo: func(p *Player) error {
					p.Stats.BasePopulation -= 1
					p.Stats.Faith -= 3
					p.Stats.Healthcare -= 2
					p.Stats.Education -= 1
					p.Stats.Secrecy += 1
					p.Stats.Cruelty += 1
					p.Stats.Madness += 1
					p.Stats.FoodSupply += 10
					return nil
				},
				CanDo: YesWeCan,
			},
			&VerbosePolicy{
				Default: &BasicPolicy{
					UnenactedDesc: cardsim.MsgStr("Rejecting all thought of worship will drive away a few kobolds."),
					EnactedDesc:   cardsim.MsgStr("Persisting in your rejection of worship will change nothing."),
					Do: func(p *Player) (cardsim.Message, error) {
						p.Stats.BasePopulation -= 30
						return cardsim.MsgStr("A few kobolds have left decrying your faithless tribe."), nil
					},
					Undo: func(p *Player) error {
						p.Stats.BasePopulation += 30
						return nil
					},
					CanDo: YesWeCan,
				},
				Variants: []Policy{
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Driving away a dragon tyrant is an undertaking, and a few kobolds will be lost in the process."),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Rejecting Izkren will demoralize some of your tribe.  There will be some emigrants."),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Rejecting Sobol's primacy will damage your tribe's economy.  There will be an outflow of economic migrants."),
					},
					&BasicPolicy{
						UnenactedDesc: cardsim.MsgStr("Cutting off Ektani's magic will drive kobolds away in horror, and spike death rates among those who remain."),
					},
				},
			},
		},
	}, //end of "The Foremost Deity" card
} // end of card list

func initDeck(d *cardsim.Deck[*KoboldMine]) {
	for _, c := range cards {
		d.Insert(cardsim.BottomOfDeck, c)
	}
	d.Shuffle()
}
